@@ -112,15 +112,15 @@ void cem_add_to_log(char *message,int type){
 	//Initialize if NULL
 	if (log_file==NULL){
 		gchar* outputFilename;
-		gchar* jammo_directory=configure_get_jammo_directory();
-		if (jammo_directory==NULL) //case: using CEM before configure is initialized (this is error case)
+		gchar* log_directory=configure_get_log_directory();
+		if (log_directory==NULL) //case: using CEM before configure is initialized (this is error case)
 			configure_init_directories(TRUE);
 
 		//check jammo_directory again
-		jammo_directory=configure_get_jammo_directory();
+		log_directory=configure_get_log_directory();
 		//if configure success
-		if (jammo_directory) {
-			outputFilename = g_strdup_printf("%s/%s.log",jammo_directory,timestamp);
+		if (log_directory) {
+			outputFilename = g_strdup_printf("%s/%s.log",log_directory,timestamp);
 			log_file = fopen(outputFilename, "a");
 			if (log_file==NULL)
 				printf("ERROR: CEM can't log to file '%s'\n",outputFilename);
