@@ -31,7 +31,7 @@ void themeselection_theme_clicked(TangleAction *action, GObject *source, const g
 	
 	//subthemes are 1,2,3.
 	int variation = (rand () % 3) + 1;
-	gchar* message = g_strdup_printf("Random variation is '%d'\n",variation);
+	gchar* message = g_strdup_printf("Random variation is '%d' ",variation);
 	cem_add_to_log(message,J_LOG_INFO);
 	g_free(message);
 	
