@@ -20,7 +20,7 @@ Cancel-button returns without modification.
 
 #include "../jammo.h"
 #include "../../configure.h"
-#include "../save_helper.h"
+#include "../file_helper.h"
 #include "sequencer.h"
 #include <string.h>
 
