@@ -22,6 +22,7 @@ static void on_recording_stopped(JammoSequencer* sequencer, gpointer user_data);
 static ClutterContainer *list = 0;
 static gint listItemHeight = 0;
 static gboolean isrecording_voice_comment = FALSE;
+static gboolean voice_comment_ready = FALSE;
 gchar* recording_filename;
 JammoSequencer* sequencer;
 
@@ -165,30 +166,31 @@ gboolean add_song_to_list(char* loopName, int numberOfSongs){
 void review_selected_song(ClutterActor *song){
 
 	GList *children = clutter_container_get_children(list);
-	GList *messages = NULL;
-	
+	GList* messages = NULL;
 	//TODO: get messages to list
 	message *msg;
 	int i;
 	time_t now;
-	
+
+	if(isrecording_voice_comment)
+		stop_recording();
+
 	for(i = 0; i < 3 /*this should be the number of messages*/; i++){
 		msg = malloc(sizeof (message));
 
-		msg->index = 0; //Index of this question. 
+		msg->index = 0; //Index of this comment
 
-		msg->msg = malloc(strlen("Message#1")+1);
+		msg->msg = malloc(strlen("Message#1")+sizeof(char));
 		sprintf(msg->msg, "Message#%d", i+1);
 		strcpy(msg->avatar, "x");
 		strcpy(msg->title, "");
 		strcpy(msg->sender, "Teppo");
 		strcpy(msg->time, "21.1.2011 10:09");
+		strcpy(msg->filepath, g_strdup_printf("%s/last_recorded.ogg",configure_get_jammo_directory()) );
+		msg->type = VOICE_COMMENT;
 
 		messages = g_list_append(messages, (gpointer)msg);
 	}
-
-	if(isrecording_voice_comment)
-		stop_recording();
 	
 	int first = 0;
 	
@@ -203,7 +205,7 @@ void review_selected_song(ClutterActor *song){
 		
 			if(song == children->data){
 				puts("found it");
-				clear_container(list);	
+				clear_container(list);
 				ClutterActor* mainview = jammo_get_actor_by_id("main-views-widget");
 				clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(tangle_actor_hide_animated), NULL);
 				start_thread_view(messages, "jammosongs", NULL, 0);
@@ -267,15 +269,19 @@ void record_voice_comment(){
 	jammo_sequencer_play(JAMMO_SEQUENCER(sequencer));
 }
 
+
+
 void stop_recording()
 {
 	isrecording_voice_comment = FALSE;
+	voice_comment_ready = TRUE;
 	jammo_sequencer_stop(JAMMO_SEQUENCER(sequencer));
 }
 
 static void on_recording_stopped(JammoSequencer* sequencer, gpointer user_data) 
 {
 	g_print("Stopped recording.\n");
+	voice_comment_ready = TRUE;
 	isrecording_voice_comment = FALSE;
 }
 
