@@ -13,12 +13,9 @@ This file contains the functionality of JamMo Songs menu.
 void start_jammosongs();
 void end_jammosongs(TangleButton *tanglebutton, gpointer none);
 gboolean add_song_to_list(char* loop_name, int number);
-static void autoscroll_to_correct_pos(ClutterActor *listToScroll);
-static void import_selected_song(ClutterActor*);
 void record_voice_comment();
 void stop_recording();
 void rec_press_action();
-static void on_recording_stopped(JammoSequencer* sequencer, gpointer user_data);
 void review_selected_song(ClutterActor*);
 
 #endif 
