@@ -4,6 +4,8 @@
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
+#include <meam/jammo-meam.h>
+#include <meam/jammo-sample.h>
 #include "../jammo.h"
 #include "community_utilities.h"
 #include "jammosongs.h"
@@ -16,6 +18,7 @@ static int selected_index = 0;
 static GList* messages;
 static gchar *id;
 static TextField text;
+gchar filepath [150];
 
 void start_thread_view(GList* listOfMessages, gchar *id_, gchar *params, int index){
 
@@ -45,7 +48,7 @@ void start_thread_view(GList* listOfMessages, gchar *id_, gchar *params, int ind
 
 		if(strcmp(id, "jammosongs") == 0){
 			text.text = jammo_get_actor_by_id("answer-field");
-			text.lineCount = 8;
+			text.lineCount = 6;
 			text.handler_id = g_signal_connect_swapped(text.text, "text-changed", (GCallback)limit_line_count, &text);
 
 		}else if(strcmp(id, "discuss") == 0){
@@ -92,6 +95,7 @@ void add_message_to_list(gpointer data, int i)
 	{
 		int index = 0;
 		int MAX = 500;
+		int h = 80;
 	
 		ClutterActor* messageBackground = 0;
 		ClutterContainer *listContainer = CLUTTER_CONTAINER(clutter_group_new());
@@ -130,17 +134,31 @@ void add_message_to_list(gpointer data, int i)
 		clutter_actor_set_position(date, 600, 10);
 		clutter_container_add_actor(listContainer, date);
 
+		
+		if(msg->type == VOICE_COMMENT){
+			
+			strcpy(filepath, msg->filepath);
+
+			ClutterActor* play_button = 0;
+			play_button = tangle_button_new_with_background_actor(clutter_texture_new_from_file("/opt/jammo/buttons/play-button.png", NULL)); 
+			clutter_actor_set_position(play_button, 400, 1);
+			clutter_container_add_actor(listContainer, play_button);
+
+			g_signal_connect_swapped(CLUTTER_ACTOR(play_button), "clicked", G_CALLBACK(play_selected_loop), filepath);
+
+		}
+
 		//clutter_actor_set_size(message,(88*7)+40, ((MAX/88)*27));
 		clutter_actor_set_width(message, (88*7)+40);
 		clutter_text_set_max_length(CLUTTER_TEXT(message), MAX);
 		clutter_actor_set_position(message, 80, 80); 
 		clutter_container_add_actor(listContainer, message);
 
+		h = (clutter_actor_get_height(avatar) + pango_layout_get_line_count(clutter_text_get_layout(CLUTTER_TEXT(message)))*25);		
+
 		messageBackground = clutter_rectangle_new_with_color(&line_color);
 		clutter_actor_set_size(messageBackground, 800, 2);
 
-		int h = (clutter_actor_get_height(avatar) + pango_layout_get_line_count(clutter_text_get_layout(CLUTTER_TEXT(message)))*25);
-
 		clutter_actor_set_position(avatar, 10, 1);
 		clutter_container_add_actor(listContainer, avatar);
 
@@ -179,41 +197,11 @@ void add_comment(){
 
 void end_single_thread(){
 
-	messages = g_list_first(messages);
-
-	//GList *returnableList = messages;
-
-/*
-	message *temp = 0;
-
-	if(messages != NULL){
-		
-		temp = messages->data;
-
-		if(temp->msg != NULL)
-		free(temp->msg);
-
-		if(messages->data != NULL)
-		free(messages->data);
-	
-		while(messages->next != NULL)
-		{
-			messages = messages->next;
-				
-			temp = messages->data;
-
-			if(temp->msg != NULL)
-			free(temp->msg);
-				
-			if(messages->data != NULL)
-			free(messages->data);				
-		}
-	
-	}
 
+	clear_messagelist(messages);
 
 	g_list_free(g_list_first(messages));	
-*/
+
 	clear_container(messageList);
 
 	if(strcmp(id, "helpdesk") == 0 )
