@@ -3,8 +3,8 @@
 
 #include <glib.h>
 
-void start_thread_view(GList*, gchar *id_, gchar *params);
-void add_message_to_list(gpointer);
+void start_thread_view(GList*, gchar *id_, gchar *params, int index);
+void add_message_to_list(gpointer data, int i);
 void add_comment();
 void end_single_thread();
 
