@@ -91,7 +91,7 @@ ClutterActor* jammo_editing_track_view_new(JammoEditingTrack* track, guint n_slo
 
 
 static void on_sample_duration_notify(GObject* object, GParamSpec* pspec, gpointer user_data) {
-	printf("on_sample_duration_notify\n");
+	//printf("on_sample_duration_notify\n");
 	TangleVault* vault;
 	JammoSampleButton* sample_button;
 	JammoEditingTrackView* track_view;
