@@ -31,6 +31,7 @@ enum {
 enum {
 	LISTENED,
 	DRAG_BEGIN,
+	DROPPED,
 	LAST_SIGNAL
 };
 
@@ -62,6 +63,7 @@ GType jammo_sample_type_get_type(void) {
 	return type;
 }
 
+
 static guint signals[LAST_SIGNAL] = { 0 };
 
 static void on_drag_begin(ClutterDragAction* action, ClutterActor* actor, gfloat event_x, gfloat event_y, ClutterModifierType modifiers, gpointer user_data);
@@ -226,6 +228,10 @@ void jammo_sample_button_set_text(JammoSampleButton* sample_button, const gchar*
 	}
 }
 
+void jammo_sample_button_on_dropped(JammoSampleButton* sample_button) {
+	g_signal_emit(sample_button, signals[DROPPED], 0);
+}
+
 static void jammo_sample_button_constructed(GObject* object) {
 	JammoSampleButton* sample_button;
 	
@@ -474,6 +480,12 @@ static void jammo_sample_button_class_init(JammoSampleButtonClass* sample_button
 					 g_cclosure_marshal_VOID__VOID,
 					 G_TYPE_NONE, 0);
 
+	signals[DROPPED] = g_signal_new("dropped", G_TYPE_FROM_CLASS(gobject_class),
+	                                 G_SIGNAL_RUN_LAST, 0,
+					 NULL, NULL,
+					 g_cclosure_marshal_VOID__VOID,
+					 G_TYPE_NONE, 0);
+
 	g_type_class_add_private(gobject_class, sizeof(JammoSampleButtonPrivate));
 }
 
