@@ -8,6 +8,7 @@ static gchar* COMPOSITIONS_DIRECTORY=NULL; //3-6 composings
 static gchar* SINGINGS_DIRECTORY=NULL;     //3-6 singings
 static gchar* PROJECTS_DIRECTORY=NULL;     //7-12 working versions
 static gchar* FINALIZED_DIRECTORY=NULL;    //7-12 audio files
+static gchar* LOG_DIRECTORY=NULL;    	   //Log files
 
 static void make_directory(gchar* directory) {
 	gchar* cmd;
@@ -38,6 +39,7 @@ void configure_init_directories(gboolean small_game){
 	if (small_game) {
 		COMPOSITIONS_DIRECTORY = g_strdup_printf("%s/compositions",JAMMO_DIRECTORY);
 		SINGINGS_DIRECTORY = g_strdup_printf("%s/singings",JAMMO_DIRECTORY);
+		LOG_DIRECTORY = g_strdup_printf("%s/logs3_6",JAMMO_DIRECTORY);
 
 		make_directory(COMPOSITIONS_DIRECTORY);
 		make_directory(SINGINGS_DIRECTORY);
@@ -54,11 +56,13 @@ void configure_init_directories(gboolean small_game){
 	else	{
 		PROJECTS_DIRECTORY = g_strdup_printf("%s/projects",JAMMO_DIRECTORY);
 		FINALIZED_DIRECTORY = g_strdup_printf("%s/finalized",JAMMO_DIRECTORY);
+		LOG_DIRECTORY = g_strdup_printf("%s/logs7_12",JAMMO_DIRECTORY);
 
 		make_directory(PROJECTS_DIRECTORY);
 		make_directory(FINALIZED_DIRECTORY);
 	}
 
+	make_directory(LOG_DIRECTORY);
 }
 
 void configure_release_directories(){
@@ -67,6 +71,7 @@ void configure_release_directories(){
 	if (SINGINGS_DIRECTORY) g_free(SINGINGS_DIRECTORY);
 	if (PROJECTS_DIRECTORY) g_free(PROJECTS_DIRECTORY);
 	if (FINALIZED_DIRECTORY) g_free(FINALIZED_DIRECTORY);
+	if (LOG_DIRECTORY) g_free(LOG_DIRECTORY);
 }
 
 
@@ -90,3 +95,6 @@ gchar* configure_get_projects_directory(){
 gchar* configure_get_finalized_directory(){
 	return FINALIZED_DIRECTORY;
 }
+gchar* configure_get_log_directory(){
+	return LOG_DIRECTORY;
+}
