@@ -238,7 +238,7 @@ guint ProfileManager::getEncryptedProfileSize()
 
 gboolean ProfileManager::setSalt(guchar* _salt)
 {
-	if(!iStorageAgent->isAuthenticated()) return iStorageAgent->setSalt(_salt);
+	if(iStorageAgent->isAuthenticated()) return iStorageAgent->setSalt(_salt);
 	else return FALSE;
 }
 
@@ -372,6 +372,13 @@ guint32 profilemanager_get_points(ProfileManager* _aManager)
 	return (guint32)strtoul((_aManager->ViewDetail(param)).c_str(),NULL,10);
 }
 
+/* Get avatar id */
+guint32 profilemanager_get_avatarid(ProfileManager* _aManager)
+{
+	string param = string(PROF_PARAM_AVATARID);
+	return (guint32)strtoul((_aManager->ViewDetail(param)).c_str(),NULL,10);
+}
+
 gboolean profilemanager_set_username(ProfileManager* _aManager, gchar* _value)
 {
 	string param = string(PROF_PARAM_USERNAME);
@@ -406,6 +413,18 @@ gboolean profilemanager_set_age(ProfileManager* _aManager, guint16 _value)
 	return _aManager->EditDetails(param,value);
 }
 
+gboolean profilemanager_set_avatarid(ProfileManager* _aManager, guint32 _value)
+{
+	string param = string(PROF_PARAM_AVATARID);
+	
+	stringstream strvalue;
+	strvalue << _value;
+	
+	string value = strvalue.str();
+	
+	return _aManager->EditDetails(param,value);
+}
+
 gboolean profilemanager_add_points(ProfileManager* _aManager, guint32 _value)
 {
 	string param = string(PROF_PARAM_POINTS);
