@@ -333,8 +333,10 @@ gboolean StorageAgent::setAuthenticated()
 
 gboolean StorageAgent::loadEncryptedProfile(gchar* username)
 {
+	if(username == NULL) return FALSE;
+	
 	// Profile was succesfully loaded before
-	if(profileloaded) return TRUE;
+	if(profileloaded) return TRUE; // TODO check if user is the same as previously loaded!
 	
 	switch(readProfile(username))
 	{
@@ -343,6 +345,7 @@ gboolean StorageAgent::loadEncryptedProfile(gchar* username)
 			return TRUE;
 		case 1:
 		case 2:
+		case 3:
 		default:
 			return FALSE;
 	}
@@ -350,6 +353,8 @@ gboolean StorageAgent::loadEncryptedProfile(gchar* username)
 
 gboolean StorageAgent::saveEncryptedProfile(gchar* username)
 {
+	if(username == NULL) return FALSE;
+	
 	switch(writeProfile(username))
 	{
 		// Errors accessing file
@@ -382,7 +387,7 @@ gboolean StorageAgent::deserializeProfile(gchar* profile)
 	
 	if(profile == NULL) return FALSE;
 	
-	if(Tokenize(string(profile), tokens, ",") != 7)	return FALSE;
+	if(Tokenize(string(profile), tokens, ",") != 8)	return FALSE;
 	
 	// Save all the details to profileDetails container
 	profileDetails[PROF_PARAM_USERID] = tokens[0];
@@ -392,6 +397,7 @@ gboolean StorageAgent::deserializeProfile(gchar* profile)
 	profileDetails[PROF_PARAM_LASTNAME] = tokens[4];
 	profileDetails[PROF_PARAM_POINTS] = tokens[5];
 	profileDetails[PROF_PARAM_AGE] = tokens[6];
+	profileDetails[PROF_PARAM_AVATARID] = tokens[7];
 	
 	return TRUE;
 }
@@ -405,7 +411,8 @@ gchar* StorageAgent::serializeProfile()
 	  profileDetails[PROF_PARAM_FIRSTNAME] + "," +
 	  profileDetails[PROF_PARAM_LASTNAME] + "," + 
 	  profileDetails[PROF_PARAM_POINTS] + "," +
-	  profileDetails[PROF_PARAM_AGE];
+	  profileDetails[PROF_PARAM_AGE] + "," + 
+	  profileDetails[PROF_PARAM_AVATARID];
 	  
 	gchar* c_serialized = g_strdup(serialized.c_str());
 	return c_serialized;
@@ -457,7 +464,7 @@ gboolean StorageAgent::setPasswordHash(guchar* _password_hash)
 	if(_password_hash == NULL) return FALSE;
 	
 	// Clear old hash
-	if(password_hash != NULL) g_free(_password_hash);
+	if(password_hash != NULL) g_free(password_hash);
 	
 	password_hash = (guchar*)g_malloc(sizeof(guchar*)*SHA_HASH_LENGTH);
 	memset(password_hash,0,SHA_HASH_LENGTH);
