@@ -53,7 +53,14 @@ public:
 	// Clear all the user details
 	gboolean clearDetails();
 	
+	gboolean isAuthenticated();
+	gboolean setAuthenticated();
+	
 	gboolean loadEncryptedProfile(gchar* username);
+	gboolean saveEncryptedProfile(gchar* username);
+	
+	gboolean deserializeProfile(gchar* profile);
+	gchar* serializeProfile();
 	
 	guchar* getSalt();
 	guchar* getPasswordHash();
@@ -61,9 +68,9 @@ public:
 	guchar* getEncryptedProfile();
 	guint getEncryptedProfileSize();
 	
-	void setSalt(guchar* _salt);
-	void setPasswordHash(guchar* _password_hash);
-	void setEncryptedProfile(guchar* _profile_hash, guchar* _encrypted_profile, guint _e_profile_size);
+	gboolean setSalt(guchar* _salt);
+	gboolean setPasswordHash(guchar* _password_hash);
+	gboolean setEncryptedProfile(guchar* _profile_hash, guchar* _encrypted_profile, guint _e_profile_size);
 	
 	void clearEncryptedData();
 	
@@ -82,9 +89,12 @@ private:
 	guchar* encrypted_profile;
 	guint encrypted_profile_size;
 	
+	gboolean authenticated;
+	gboolean profileloaded;
+	
 	// This function removes the unneccesary symbols
-	// From the lines read
-	void Tokenize(const string& str,
+	// From the lines read - returns amount of elements
+	gint Tokenize(const string& str,
 			  vector<string>& tokens,
 			  const string& delimiters);
 };
