@@ -532,7 +532,7 @@ void print_list(GList* list)
 		printf("%d: state: %d (data in buffer: %d bytes) | %s / %d\n",
 			g_list_position(list,iterator), element->connection_state, gems_connection_partial_data_amount(element),
 			ph_c_connection_get_remote_address(element->connection), ph_c_connection_get_device_checksum(element->connection));
-		if(element->profile != NULL) printf("\tProfile: %u:%s, %dyo avatarid: %d\n",
+		if(element->profile != NULL) printf("\tProfile: %u:%s, %dyo avatarid: %u\n",
 			element->profile->id,element->profile->username,element->profile->age,element->profile->avatarid);
 	}
 }
@@ -1122,15 +1122,28 @@ gboolean gems_communication_process_data(gems_connection* element)
 				success = FALSE; // TODO change to add a "invalid message" to errors
 			}
 			
+			break;
+		case MENTOR_SERVICE_ID:
+			// Check that service is running
+			if(data->service_mentor->enabled == TRUE) success = gems_service_mentor_process_request(element);
+			else
+			{
+				err = gems_create_error_message(ERROR_SERVICE_NOT_RUNNING_TYPE, MENTOR_SERVICE_ID);
+				if(gems_communication_write_data(ph_c_connection_get_fd(element->connection),err) != err->length)
+				{
+					logmsg = g_strdup_printf("gems_service_jammo_process_connections: cannot write ERROR_SERVICE_NOT_RUNNING");
+					cem_add_to_log(logmsg, J_LOG_ERROR);
+					g_free(logmsg);
+				}
+				gems_clear_message(err);
+				success = FALSE; // TODO change to add a "invalid message" to errors
+			}
+			
 			break;
 		/*case SONGBANK_SERVICE_ID:
 			break;
 		case DATATRANSFER_SERVICE_ID:
 			break;
-		case MENTOR_SERVICE_ID:
-			break;
-		case CONTROL_SERVICE_ID:
-			break;	
 		case PROBE_SERVICE_ID:
 			break;*/
 		case ERROR_MSG:
@@ -1570,9 +1583,12 @@ gboolean gems_teacher_connection_disconnect()
 		gems_clear_gems_connection(data->teacher_connection->connection);
 		data->teacher_connection->connection = NULL;
 		
-		gchar* logmsg = g_strdup_printf("gems_teacher_connection_disconnect: connection to teacher was disconnected");
+		data->timeout_functions[9] = g_timeout_add_full(G_PRIORITY_HIGH,100,(GSourceFunc)gems_communication_search_teacher, NULL, NULL);
+		
+		gchar* logmsg = g_strdup_printf("gems_teacher_connection_disconnect: connection to teacher was disconnected. Teacher search re-enabled.");
 		cem_add_to_log(logmsg,J_LOG_DEBUG);
 		g_free(logmsg);
+		
 		return TRUE;
 	}
 	else return FALSE;
@@ -1611,3 +1627,69 @@ gboolean gems_communication_do_profile_request_to_teacher(gchar* username)
 	
 	return rval;
 }
+
+gint gems_communication_search_teacher()
+{
+	gchar* logmsg = NULL;
+	gems_components* data = gems_get_data();	
+	
+	if(data == NULL) return FALSE;
+	if(data->ph == NULL) return FALSE; // no PeerHood = no network
+	if(gems_teacher_connection_is_connected()) return FALSE; // Already connected
+	
+	// Get surrounding devices with service JAMMO_SERVICE_NAME 
+	TDeviceList* list = ph_c_get_devicelist_with_services(data->ph,MENTOR_SERVICE_NAME);
+	// Got a NULL reference - error with PeerHood -> stop it
+	if(list == NULL)
+	{
+		logmsg = g_strdup_printf("gems_communication_search_teacher: connection to PeerHood daemon was lost.");
+		cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
+		g_free(logmsg);
+		gems_communication_peerhood_close_detected();
+		return FALSE;
+	}
+	
+	if(ph_c_devicelist_is_empty(list) == FALSE)
+	{
+		// Initialize wrapper for iterator for list
+		DeviceIterator* iterator = ph_c_new_device_iterator(list);
+		
+		if(iterator == NULL)
+		{
+			ph_c_delete_devicelist(list);
+			return FALSE;
+		}
+		
+		// Go through list - there should be only one teacher
+		for(iterator = ph_c_new_device_iterator(list); ph_c_device_iterator_is_last(iterator,list) != TRUE; ph_c_device_iterator_next_iterator(iterator))
+		{
+			// Get the device
+			MAbstractDevice* dev = ph_c_device_iterator_get_device(iterator);
+			
+			// Through WLAN and has peerhood? - all devices in the list should have ph enabled
+			if((strcmp(ph_c_device_get_prototype(dev),"wlan-base") == 0) && (ph_c_device_has_peerhood(dev) == TRUE))
+			{
+				MAbstractConnection* conn = NULL;
+				if((conn = ph_c_connect_remoteservice(data->ph, dev, MENTOR_SERVICE_NAME)) != NULL)
+				{
+					// set connection
+					gems_get_teacher_connection()->connection = gems_new_gems_connection(conn, 0, 0, JAMMO_CONNECTED_NO_AUTH, 0);
+					
+					logmsg = g_strdup_printf("gems_communication_search_jammos: Connected to new teacher device %s/%d",
+						ph_c_device_get_name(dev),ph_c_device_get_checksum(dev));
+					cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
+					g_free(logmsg);
+					
+					// Connection established, leave
+					break;
+				}
+			}
+		} // for
+		// Delete the iterator
+		ph_c_delete_device_iterator(iterator);
+	}
+	// Delete the list of devices
+	ph_c_delete_devicelist(list);
+	
+	return TRUE;
+}
