@@ -48,6 +48,7 @@ gems_components* gems_get_data()
 		gems_data->service_profile = NULL;
 		gems_data->service_group = NULL;
 		gems_data->service_control = NULL;
+		gems_data->service_mentor = NULL;
 		gems_data->initialized_connections = NULL;
 		gems_data->connection_errorlist = NULL;
 		gems_data->service_collaboration = NULL;
@@ -117,6 +118,11 @@ gems_service_control* gems_get_service_control()
 	return gems_get_data()->service_control;
 }
 
+gems_service_mentor* gems_get_service_mentor()
+{
+	return gems_get_data()->service_mentor;
+}
+
 GList* gems_get_errorlist()
 {
 	return gems_get_data()->connection_errorlist;
@@ -166,7 +172,7 @@ void jammo_gems_init(int argc, char* argv[])
 	gems_components* components = gems_get_data();
 	
 	// Initialize timeout function id table
-	for(gint i = 0; i < 9; i++) components->timeout_functions[i] = 0;
+	for(gint i = 0; i < TO_FUNCTIONS; i++) components->timeout_functions[i] = 0;
 	
 	// Profile manager
 	components->pm = profilemanager_new_manager();
@@ -259,7 +265,7 @@ void jammo_gems_cleanup()
 	g_free(logmsg);
 	
 	// Remove timeout functions
-	for(gint i = 0; i<9; i++) g_source_remove(components->timeout_functions[i]);
+	for(gint i = 0; i < TO_FUNCTIONS; i++) g_source_remove(components->timeout_functions[i]);
 	
 	if(components->pm != NULL) profilemanager_delete_manager(components->pm);
 	
@@ -270,23 +276,44 @@ void jammo_gems_cleanup()
 	gems_communication_cleanup();
 	
 	// Clear Profile service related
-	if(components->service_profile->enabled == TRUE) ph_c_unregister_service(components->ph,PROFILE_SERVICE_NAME);
-	gems_service_profile_cleanup();
+	if(components->service_profile)
+	{
+		if(components->service_profile->enabled == TRUE) ph_c_unregister_service(components->ph,PROFILE_SERVICE_NAME);
+		gems_service_profile_cleanup();
+	}
 	
 	// Clear JamMo service related
-	if(components->service_jammo->enabled == TRUE) ph_c_unregister_service(components->ph,JAMMO_SERVICE_NAME);
-	gems_service_jammo_cleanup();
+	if(components->service_jammo)
+	{
+		if(components->service_jammo->enabled == TRUE) ph_c_unregister_service(components->ph,JAMMO_SERVICE_NAME);
+		gems_service_jammo_cleanup();
+	}
 	
 	// Clear Group management service related
-	if(components->service_group->enabled == TRUE) ph_c_unregister_service(components->ph,GROUP_SERVICE_NAME);
-	gems_service_group_cleanup();
+	if(components->service_group)
+	{
+		if(components->service_group->enabled == TRUE) ph_c_unregister_service(components->ph,GROUP_SERVICE_NAME);
+		gems_service_group_cleanup();
+	}
 	
 	// Clear Collaboration service related
-	if(components->service_collaboration->enabled == TRUE) ph_c_unregister_service(components->ph,COLLABORATION_SERVICE_NAME);
-	gems_service_collaboration_cleanup();
+	if(components->service_collaboration)
+	{
+		if(components->service_collaboration->enabled == TRUE) ph_c_unregister_service(components->ph,COLLABORATION_SERVICE_NAME);
+		gems_service_collaboration_cleanup();
+	}
 	
-	if(components->service_control->enabled == TRUE) ph_c_unregister_service(components->ph,CONTROL_SERVICE_NAME);
-	gems_service_control_cleanup();
+	if(components->service_control)
+	{
+		if(components->service_control->enabled == TRUE) ph_c_unregister_service(components->ph,CONTROL_SERVICE_NAME);
+		gems_service_control_cleanup();
+	}
+
+	if(components->service_mentor)
+	{
+		if(components->service_mentor->enabled == TRUE) ph_c_unregister_service(components->ph,MENTOR_SERVICE_NAME);
+		gems_service_mentor_cleanup();
+	}
 	
 	gems_clear_teacher_connection();
 	
@@ -337,13 +364,14 @@ void jammo_gems_cleanup_lists()
 
 void gems_list_profile_parameters()
 {
-	printf("OWN PROFILE (%u):\nusername:\t%s\nfull name:\t%s %s\nuser age:\t%d\ntotal points:\t%d\n",
+	printf("OWN PROFILE (%u):\nusername:\t%s\nfull name:\t%s %s\nuser age:\t%d\ntotal points:\t%d\navatar:\t%u\n",
 		gems_profile_manager_get_userid(NULL),
 		gems_profile_manager_get_username(NULL),
 		gems_profile_manager_get_firstname(),
 		gems_profile_manager_get_lastname(),
 		gems_profile_manager_get_age(NULL),
-		gems_profile_manager_get_points());
+		gems_profile_manager_get_points(),
+		gems_profile_manager_get_avatar_id(NULL));
 }
 
 /*Forward the messages to collaboration module */
@@ -862,12 +890,19 @@ gint gems_process_connections()
 					cleanup_required = TRUE;
 			}
 		}
-		if(logmsg != NULL) cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
-		g_free(logmsg);
-		logmsg = NULL;
-		if(logerror != NULL) cem_add_to_log(logerror,J_LOG_ERROR);
-		g_free(logerror);
-		logerror = NULL;
+		if(logmsg != NULL)
+		{
+			cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
+			g_free(logmsg);
+			logmsg = NULL;
+		}
+		
+		if(logerror != NULL)
+		{
+			cem_add_to_log(logerror,J_LOG_ERROR);
+			g_free(logerror);
+			logerror = NULL;
+		}
 		
 		// next in line
 		iterator = g_list_next(iterator);
@@ -1064,6 +1099,7 @@ void gems_enable_network_timeout_functions()
 	gems_get_data()->timeout_functions[6] = g_timeout_add_full(G_PRIORITY_HIGH,500,(GSourceFunc)gems_communication_process_rejected, NULL, NULL);
 	gems_get_data()->timeout_functions[7] = g_timeout_add_full(G_PRIORITY_HIGH,200,(GSourceFunc)gems_communication_request_groups, NULL, NULL);
 	gems_get_data()->timeout_functions[8] = g_timeout_add_full(G_PRIORITY_HIGH,350,(GSourceFunc)gems_communication_sanitize_grouplist, NULL, NULL);
+	gems_get_data()->timeout_functions[9] = g_timeout_add_full(G_PRIORITY_HIGH,1000,(GSourceFunc)gems_communication_search_teacher, NULL, NULL);
 }
 
 void gems_register_services()
