@@ -171,6 +171,7 @@ typedef enum
 #define REQ_ENC_PROFILE 1026
 #define PROFILE_ENC 1027
 #define PROFILE_SET_UNAME 1028
+#define PROFILE_PASSCHANGED 1029
 
 // GROUP SERVICE
 #define REQUEST_MEMBERS 1030
@@ -203,6 +204,10 @@ typedef enum
 // CONTROL SERVICE
 #define CONTROL_MODE 1060
 #define CONTROL_OK 1061
+#define CONTROL_SET_LOGIN 1062
+
+// MENTOR SERVICE
+#define LOG_MESSAGE 1070
 
 // Group types
 #define GROUP_TYPE_PAIR 10311
@@ -266,6 +271,7 @@ typedef enum
 #define PROF_PARAM_LASTNAME "lastName"
 #define PROF_PARAM_POINTS "gamePoints"
 #define PROF_PARAM_AGE "age"
+#define PROF_PARAM_AVATARID "avatarID"
 
 // Security - extraction of envelope return values
 #define SECURITY_OK 10190
