@@ -153,6 +153,8 @@ gems_message* gems_create_message_service_profile(gint16 type)
 {
 	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));
 	guint position = 0;
+	const gchar* fname = NULL;
+	const gchar* lname = NULL;
 	
 	// TODO remove this and implement enabling of profile service only when authenticated
 	if(gems_profile_manager_is_authenticated() == FALSE)
@@ -163,11 +165,32 @@ gems_message* gems_create_message_service_profile(gint16 type)
 	
 	const gchar* username = gems_profile_manager_get_username(NULL);
 	
+	if(!username)
+	{
+		g_free(msg);
+		return NULL;
+	}
+	
 	msg->length = sizeof(gint16) + sizeof(gint32) + sizeof(gint16);
 	
-	if(type == PROFILE_PUB) msg->length = msg->length + sizeof(gint32) + strlen(username) + 1 + sizeof(gint32) + sizeof(gint16);
-	// TODO full profile
-	//else if(type == PROFILE_FULL)
+	// Public parts, basic header + username length + \0 + user id + age + avatar id
+	if(type == PROFILE_PUB) msg->length = msg->length + strlen(username) + 1 + sizeof(guint32) + sizeof(guint16) + sizeof(guint32);
+	
+	// Full profile
+	if(type == PROFILE_FULL)
+	{
+		fname = gems_profile_manager_get_firstname();
+		lname = gems_profile_manager_get_lastname();
+		
+		if(!fname || !lname)
+		{
+			g_free(msg);
+			return NULL;
+		}
+		
+		// Firstname + lastname + points length
+		msg->length = msg->length + strlen(fname) + 1 + strlen(lname) + 1 + sizeof(guint32);
+	}
 		
 	msg->message = (gchar*)g_malloc(sizeof(gchar*) * msg->length);
 	
@@ -200,13 +223,28 @@ gems_message* gems_create_message_service_profile(gint16 type)
 	position = position + sizeof(guint16);
 	
 	// Avatar id
-	guint16 avatarid = gems_profile_manager_get_avatar_id(NULL);
-	*(guint16*)&msg->message[position] = g_htons(avatarid);
-	//position = position + sizeof(gint16);
+	guint32 avatarid = gems_profile_manager_get_avatar_id(NULL);
+	*(guint32*)&msg->message[position] = g_htonl(avatarid);
+	position = position + sizeof(gint32);
 	
 	if(type == PROFILE_PUB) return msg;
-	// TODO add full profile info
-	else if(type == PROFILE_FULL) return msg;
+	// add full profile info
+	else if(type == PROFILE_FULL)
+	{
+		// firstname
+		g_strlcat(&msg->message[position],fname,msg->length);
+		position = strlen(fname) + 1;
+		
+		// lastname
+		g_strlcat(&msg->message[position],lname,msg->length);
+		position = strlen(lname) + 1;
+		
+		// points
+		guint32 points = gems_profile_manager_get_points();
+		*(guint32*)&msg->message[position] = g_htonl(points);
+		
+		return msg;
+	}
 	else
 	{
 		gems_clear_message(msg);
@@ -310,6 +348,41 @@ gems_message* gems_create_message_teacher_service_profile_reply(gchar* data, gui
 	return msg;
 }
 
+gems_message* gems_create_message_password_changed(guchar* newpasshash, gchar* encnewpass, guint encpasslen)
+{
+	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));
+	guint position = 0;
+	
+	msg->length = sizeof(gint16) + sizeof(gint32) + sizeof(gint16) + sizeof(guint32) + SHA_HASH_LENGTH + encpasslen ;
+	
+	msg->message = (gchar*)g_malloc0(sizeof(gchar*) * msg->length);
+	
+	// Service id 16 bits
+	*(gint16*)&msg->message[position] = g_htons(TEACHER_PROFILE_SERVICE_ID);
+	position = position + sizeof(gint16);
+	
+	// Length 32 bits
+	*(gint32*)&msg->message[position] = g_htonl(msg->length);
+	position = position + sizeof(gint32);
+	
+	// Command 16 bits
+	*(gint16*)&msg->message[position] = g_htons(PROFILE_PASSCHANGED);
+	position = position + sizeof(gint16);
+	
+	// Userid 32 bits
+	*(guint32*)&msg->message[position] = g_htonl(gems_profile_manager_get_userid(NULL));
+	position = position + sizeof(guint32);
+	
+	// hash of the new password
+	g_memmove(&msg->message[position],newpasshash,SHA_HASH_LENGTH);
+	position = position + SHA_HASH_LENGTH;
+	
+	// new password encrypted with old password
+	g_memmove(&msg->message[position],encnewpass,encpasslen);
+	position = position + encpasslen;
+	
+	return msg;
+}
 
 /* Use with notify messages which do not need the group information, for sending:
 		- REQUEST_GROUP_INFO
@@ -845,3 +918,64 @@ gems_message* gems_create_message_control_ok(gint16 type)
 
 	return msg;
 }
+
+gems_message* gems_create_message_control_set_login_name(gchar* username)
+{
+	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));
+	guint position = 0;
+	
+	msg->length = sizeof(gint16) + sizeof(gint32) + sizeof(gint16) + strlen(username) + 1;
+	
+	msg->message = (gchar*)g_malloc(sizeof(gchar*) * msg->length);
+	
+	memset(msg->message,'\0',msg->length);
+	
+	// Service id 16 bits
+	*(gint16*)&msg->message[position] = g_htons(CONTROL_SERVICE_ID);
+	position = position + sizeof(gint16);
+	
+	// Length 32 bits
+	*(gint32*)&msg->message[position] = g_htonl(msg->length);
+	position = position + sizeof(gint32);
+	
+	// Command 16 bits
+	*(gint16*)&msg->message[position] = g_htons(CONTROL_SET_LOGIN);
+	position = position + sizeof(gint16);
+	
+	// Username
+	g_strlcat(&msg->message[position],username,strlen(username)+1);
+	position = position + strlen(username) + 1;
+	
+	return msg;
+}
+
+gems_message* gems_create_message_mentor_log_message(gint16 type, char *message)
+{
+	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));
+	guint position = 0;
+	
+	msg->length = sizeof(gint16) + sizeof(gint32) + sizeof(gint16) + strlen(message) + 1;
+	
+	msg->message = (gchar*)g_malloc(sizeof(gchar*) * msg->length);
+	
+	memset(msg->message,'\0',msg->length);
+	
+	// Service id 16 bits
+	*(gint16*)&msg->message[position] = g_htons(MENTOR_SERVICE_ID);
+	position = position + sizeof(gint16);
+	
+	// Length 32 bits
+	*(gint32*)&msg->message[position] = g_htonl(msg->length);
+	position = position + sizeof(gint32);
+	
+	// Command 16 bits
+	*(gint16*)&msg->message[position] = g_htons(type);
+	position = position + sizeof(gint16);
+	
+	// Log message
+	g_strlcat(&msg->message[position],message,msg->length);
+	
+	return msg;
+
+
+}
