@@ -29,6 +29,8 @@ gems_message* gems_create_message_teacher_service_profile_request(gchar* usernam
 
 gems_message* gems_create_message_teacher_service_profile_reply(gchar* data, guint length, gchar* username);
 
+gems_message* gems_create_message_password_changed(guchar* newpasshash, gchar* encnewpass, guint encpasslen);
+
 gems_message* gems_create_message_group_management_notify(gint16 type, guint32 groupid, guint32 member);
 
 gems_message* gems_create_message_group_management_group_info(gint16 type);
@@ -47,5 +49,7 @@ gems_message* gems_create_message_collaboration_action_slider_series(gint16 type
 
 gems_message* gems_create_message_control_mode(gint16 type, gint16 cntrl_type, gint16 lock_mode);
 gems_message* gems_create_message_control_ok(gint16 type);
+gems_message* gems_create_message_control_set_login_name(gchar* username);
 
+gems_message* gems_create_message_mentor_log_message(gint16 type, char *message);
 #endif // __GEMS_MESSAGE_FUNCTIONS
