@@ -70,7 +70,15 @@ guint16 gems_profile_manager_get_age(gems_peer_profile* profile);
  *
  * Returns:
  */
-guint16 gems_profile_manager_get_avatar_id(gems_peer_profile* profile);
+guint32 gems_profile_manager_get_avatar_id(gems_peer_profile* profile);
+
+/* Set avatar id,  if parameter is NULL return own, otherwise return value from profile 
+ *
+ * Parameter: profile - profile to use or NULL to retrieve own
+ *
+ * Returns: TRUE if set
+ */
+gboolean gems_profile_manager_set_avatar_id(guint32 avatarid);
 
 /* Get profile of user with given id
  *
