@@ -330,7 +330,7 @@ GList* gems_cleanup_connections_from_list(GList* list)
 	return list;
 }
 
-gems_peer_profile* gems_new_peer_profile(gchar* username, guint32 id, guint16 age, guint16 avatarid)
+gems_peer_profile* gems_new_peer_profile(gchar* username, guint32 id, guint16 age, guint32 avatarid)
 {
 	gems_peer_profile* profile = (gems_peer_profile*)g_malloc(sizeof(gems_peer_profile));
 	
@@ -342,7 +342,7 @@ gems_peer_profile* gems_new_peer_profile(gchar* username, guint32 id, guint16 ag
 	return profile;
 }
 
-void gems_peer_profile_set_values(gems_peer_profile* profile, gchar* username, guint32 id, guint16 age, guint16 avatarid)
+void gems_peer_profile_set_values(gems_peer_profile* profile, gchar* username, guint32 id, guint16 age, guint32 avatarid)
 {
 	profile->id = id;
 	profile->username = g_strdup(username);
@@ -399,7 +399,7 @@ void gems_connection_localize_data_in_buffer(gems_connection* element)
 					// age
 					gems_connection_add_16(element, g_ntohs(gems_connection_get_16(element,element->add_position)));
 					// avatar id
-					gems_connection_add_16(element, g_ntohs(gems_connection_get_16(element,element->add_position)));
+					gems_connection_add_32(element, g_ntohl(gems_connection_get_32(element,element->add_position)));
 					break;
 				case PROFILE_FULL:
 					break;
@@ -522,6 +522,21 @@ void gems_connection_localize_data_in_buffer(gems_connection* element)
 		case MENTOR_SERVICE_ID:
 			break;
 		case CONTROL_SERVICE_ID:
+			switch(gems_connection_get_16(element,6)) // command
+			{
+				case CONTROL_OK:
+					break;
+				case CONTROL_MODE:
+					// Control type 16 bits
+					gems_connection_add_16(element, g_ntohs(gems_connection_get_16(element, element->add_position)));
+					// Lock mode 16 bits
+					gems_connection_add_16(element, g_ntohs(gems_connection_get_16(element, element->add_position)));
+					break;
+				case CONTROL_SET_LOGIN:
+					break;
+				default:
+					break;
+			}
 			break;
 		case PROBE_SERVICE_ID:
 			break;
