@@ -29,6 +29,7 @@ jammo_profile_container* gems_teacher_server_new_profile_container()
 	container->authlevel = NULL;
 	container->age = 0;
 	container->points = 0;
+	container->avatarid = 0;
 	container->encrypted = NULL;
 	container->encrypted_length = 0;
 	return container;	
@@ -83,25 +84,25 @@ void gems_teacher_server_clear_profile_data_container(teacher_server_profile_dat
 }
 
 jammo_profile_container* gems_teacher_server_create_profile(guint32 _userid, gchar* _username, gchar* _password,
-	gchar* _authlevel, gchar* _firstname, gchar* _lastname, guint16 _age)
+	gchar* _authlevel, gchar* _firstname, gchar* _lastname, guint16 _age, guint32 _avatarid)
 {
 	// Call setup function with NULL salt and 0 points, salt will be generated when NULL
-	return gems_teacher_server_setup_profile(_userid,_username,_password,NULL,_authlevel,_firstname,_lastname,_age,0);
+	return gems_teacher_server_setup_profile(_userid,_username,_password,NULL,_authlevel,_firstname,_lastname,_age,0,_avatarid);
 }
 
 jammo_profile_container* gems_teacher_server_setup_profile(guint32 _userid, gchar* _username, gchar* _password,
-	guchar* _salt, gchar* _authlevel, gchar* _firstname, gchar* _lastname, guint16 _age, guint32 _points)
+	guchar* _salt, gchar* _authlevel, gchar* _firstname, gchar* _lastname, guint16 _age, guint32 _points, guint32 _avatarid)
 {
 	// check input
 	if((_userid == 0) || (_username == NULL) || (_password == NULL) || (_authlevel == NULL) 
 		|| (_firstname == NULL) || (_lastname == NULL) || (_age == 0)) return NULL;
 	
 	// Check params for illegal characters
-	if(gems_teacher_server_check_illegal_characters(_username)) return NULL;
-	if(gems_teacher_server_check_illegal_characters(_password)) return NULL;
-	if(gems_teacher_server_check_illegal_characters(_authlevel)) return NULL;
-	if(gems_teacher_server_check_illegal_characters(_firstname)) return NULL;
-	if(gems_teacher_server_check_illegal_characters(_lastname)) return NULL;
+	if(gems_check_illegal_characters(_username)) return NULL;
+	if(gems_check_illegal_characters(_password)) return NULL;
+	if(gems_check_illegal_characters(_authlevel)) return NULL;
+	if(gems_check_illegal_characters(_firstname)) return NULL;
+	if(gems_check_illegal_characters(_lastname)) return NULL;
 
 	jammo_profile_container* container = gems_teacher_server_new_profile_container();
 	
@@ -109,6 +110,7 @@ jammo_profile_container* gems_teacher_server_setup_profile(guint32 _userid, gcha
 	container->userid = _userid;
 	container->age = _age;
 	container->points = _points;
+	container->avatarid = _avatarid;
 	container->username = g_strdup(_username);
 	container->firstname = g_strdup(_firstname);
 	container->lastname = g_strdup(_lastname);
@@ -169,6 +171,7 @@ gboolean gems_teacher_server_encrypt_profile(jammo_profile_container* container)
 	gchar* userid = NULL;
 	gchar* age = NULL;
 	gchar* points = NULL;
+	gchar* avatarid = NULL;
 	guchar* profilehash = NULL;
 	guchar* encprofile = NULL;
 	guchar* decprofile = NULL;
@@ -184,7 +187,8 @@ gboolean gems_teacher_server_encrypt_profile(jammo_profile_container* container)
 		userid = g_strdup_printf("%u",container->userid);
 		age = g_strdup_printf("%u",container->age);
 		points = g_strdup_printf("%u",container->points);
-		profile = (guchar*)g_strjoin(",", userid, container->username, container->authlevel, container->firstname, container->lastname, points, age, NULL);
+		avatarid = g_strdup_printf("%u",container->avatarid);
+		profile = (guchar*)g_strjoin(",", userid, container->username, container->authlevel, container->firstname, container->lastname, points, age, avatarid, NULL);
 		profilelen = strlen((gchar*)profile)+1;
 	
 		// Create salt and password
@@ -242,6 +246,7 @@ gboolean gems_teacher_server_encrypt_profile(jammo_profile_container* container)
 		if(userid != NULL) g_free(userid);
 		if(age != NULL) g_free(age);
 		if(points != NULL) g_free(points);
+		if(avatarid != NULL) g_free(avatarid);
 		if(profile!= NULL) g_free(profile);
 		if(profilehash != NULL) g_free(profilehash);
 		if(encprofile != NULL) g_free(encprofile);
@@ -342,7 +347,7 @@ gchar* gems_teacher_server_serialize_all_profiles(GList* list, guint* length)
 		total_length = total_length + sizeof(guint32) + sizeof(guint8) + strlen(profile->username) + 1 + 
 			sizeof(guint8) + strlen(profile->password) + 1 + AES_SALT_LENGTH + sizeof(guint8) + 
 			strlen(profile->firstname) + 1 + sizeof(guint8) + strlen(profile->lastname) + 1 +sizeof(guint8) + 
-			strlen(profile->authlevel) + 1 + sizeof(guint16) + sizeof(guint32);
+			strlen(profile->authlevel) + 1 + sizeof(guint16) + sizeof(guint32) + sizeof(guint32);
 	}
 	
 	if((all_profiles = (gchar*)g_try_malloc0(sizeof(gchar*)*total_length)) == NULL) return NULL;
@@ -406,6 +411,10 @@ gchar* gems_teacher_server_serialize_all_profiles(GList* list, guint* length)
 		// points
 		*(guint32*)&all_profiles[position] = profile->points;
 		position = position + sizeof(guint32);
+		
+		// avatar id
+		*(guint32*)&all_profiles[position] = profile->avatarid;
+		position = position + sizeof(guint32);
 	}
 	
 	*length = total_length;
@@ -425,6 +434,7 @@ GList* gems_teacher_server_deserialize_profiles(GList* list, gchar* serialized_d
 	gchar* authlevel = NULL;
 	guint16 age = 0;
 	guint32 points = 0;
+	guint32 avatarid = 0;
 	
 	guint position = 0;
 	guint8 valuelength = 0;
@@ -493,9 +503,13 @@ GList* gems_teacher_server_deserialize_profiles(GList* list, gchar* serialized_d
 		points = *(guint32*)&serialized_data[position];
 		position = position + sizeof(guint32);
 		
+		// avatarid
+		avatarid = *(guint32*)&serialized_data[position];
+		position = position + sizeof(guint32);
+		
 		// create profile and add to list
 		if((profile = gems_teacher_server_setup_profile(id,username,password,salt,authlevel,firstname,
-			lastname,age,points)) != NULL) list = g_list_append(list,profile);
+			lastname,age,points,avatarid)) != NULL) list = g_list_append(list,profile);
 		
 		g_free(username);
 		username = NULL;
@@ -529,8 +543,8 @@ void gems_teacher_server_print_profile_list(GList* list)
 }
 void gems_teacher_server_print_profile(jammo_profile_container* profile)
 {
-	printf("%u:%s:%s:%s:%s:%s:%u:%u\n",profile->userid, profile->username, profile->password,profile->authlevel,
-		profile->firstname,profile->lastname,profile->age,profile->points);
+	printf("%u:%s:%s:%s:%s:%s:%u:%u:%u\n",profile->userid, profile->username, profile->password,profile->authlevel,
+		profile->firstname,profile->lastname,profile->age,profile->points,profile->avatarid);
 }
 
 // serialize all data and encrypt
@@ -774,23 +788,6 @@ gint gems_teacher_server_read_profile_database(teacher_server_profile_data* data
 	return rval;
 }
 
-gboolean gems_teacher_server_check_illegal_characters(gchar* data)
-{
-	// Illegal characters
-	gchar illegal[ILLEGAL_CHAR_COUNT] = ILLEGAL_CHARS;
-	
-	for(gint i = 0; i < ILLEGAL_CHAR_COUNT; i++)
-	{
-		for(gint j = 0; j < strlen(data); j++)
-		{
-			// found
-			if(data[j] == illegal[i]) return TRUE;
-		}
-	}
-	// Not found
-	return FALSE;
-}
-
 // TODO list profiles on disk
 // TODO load profiles on disk to jammo_profile_container*
 // TODO search profile by username & password hash
